@@ -766,44 +766,152 @@ Edge WebDriver not found. Please install Edge WebDriver:
                     pass
     
     def _extract_search_results(self, soup: BeautifulSoup, page_num: int) -> List[Dict[str, Any]]:
-        """Extract search results from a page."""
-        results = []
-        
-        # Look for search result items
-        result_items = soup.find_all(['article', 'div'], class_=re.compile(r'search-result|article-item'))
-        
-        for item in result_items:
+        """Extract search results from a page using multiple resilient selectors.
+
+        Improvements vs original implementation:
+        - Tries several container selectors (mirrors TS Cheerio approach)
+        - Extracts richer metadata: description_html/text, votes, comments, author, date
+        - Preserves legacy fields (snippet, metadata) for backward compatibility
+        - Adds index & page for downstream analytics
+        - Robust fallbacks & normalization of URLs
+        """
+        results: List[Dict[str, Any]] = []
+
+        # Ordered list of possible container selectors (keep broad ones last)
+        container_selectors = [
+            '.search-result-list-item',
+            '.search-results-list .search-result',
+            '.striped-list-item',
+            '.article-list-item',
+            'article.search-result',
+            'div.search-result',
+        ]
+
+        # Collect candidate elements (stop at first selector that yields results)
+        result_items = []
+        for selector in container_selectors:
+            found = soup.select(selector)
+            if found:
+                log(f"Found {len(found)} search results using selector: {selector}", "INFO")
+                result_items = found
+                break
+
+        # Fallback: regex class scan (original heuristic)
+        if not result_items:
+            fallback = soup.find_all(['article', 'div'], class_=re.compile(r'search-result|article-item'))
+            if fallback:
+                log(f"Fallback selector captured {len(fallback)} results", "INFO")
+                result_items = fallback
+            else:
+                log("No search result items found with any selector", "WARNING")
+                return results
+
+        def first_text(element, selector_list: List[str]) -> str:
+            for sel in selector_list:
+                found = element.select_one(sel)
+                if found and found.get_text(strip=True):
+                    return found.get_text(strip=True)
+            return ''
+
+        for idx, item in enumerate(result_items):
             try:
-                # Extract title
-                title_elem = item.find(['h1', 'h2', 'h3', 'h4', 'a'], class_=re.compile(r'title|heading'))
-                title = title_elem.get_text().strip() if title_elem else "No title"
-                
-                # Extract link
-                link_elem = item.find('a', href=True)
-                link = link_elem['href'] if link_elem else ""
+                # Title & link
+                title_link_elem = None
+                title_selectors = [
+                    '.search-result-title a',
+                    'h3 a',
+                    '.title a',
+                    'a'
+                ]
+                for sel in title_selectors:
+                    candidate = item.select_one(sel)
+                    if candidate and candidate.get_text(strip=True):
+                        title_link_elem = candidate
+                        break
+
+                title = title_link_elem.get_text(strip=True) if title_link_elem else 'No title'
+                link = title_link_elem.get('href') if title_link_elem and title_link_elem.has_attr('href') else ''
                 if link and not link.startswith('http'):
                     link = f"https://support.worldquantbrain.com{link}"
-                
-                # Extract snippet
-                snippet_elem = item.find(['p', 'div'], class_=re.compile(r'snippet|excerpt|summary'))
-                snippet = snippet_elem.get_text().strip() if snippet_elem else ""
-                
-                # Extract metadata
-                meta_elem = item.find(['span', 'div'], class_=re.compile(r'meta|date|author'))
-                metadata = meta_elem.get_text().strip() if meta_elem else ""
-                
+
+                if not link and not title:
+                    continue  # Skip invalid entries
+
+                # Description / snippet
+                desc_elem = None
+                desc_selectors = [
+                    '.search-results-description',
+                    '.description',
+                    '.excerpt',
+                    '.content-preview',
+                    'p'
+                ]
+                for sel in desc_selectors:
+                    candidate = item.select_one(sel)
+                    if candidate and candidate.get_text(strip=True):
+                        desc_elem = candidate
+                        break
+
+                description_html = str(desc_elem) if desc_elem else ''
+                description_text = desc_elem.get_text(strip=True) if desc_elem else ''
+
+                # Votes & comments
+                votes = first_text(item, [
+                    '.search-result-votes span',
+                    '.votes span',
+                    '[class*="vote"] span',
+                    '[class*="vote"]'
+                ]) or '0'
+                comments = first_text(item, [
+                    '.search-result-meta-count span',
+                    '.comments span',
+                    '[class*="comment"] span',
+                    '[class*="comment"]'
+                ]) or '0'
+
+                # Metadata / author / date
+                meta_block = item.select_one('.meta-data, .metadata, .post-meta')
+                author = 'Unknown'
+                date_val = 'Unknown'
+                if meta_block:
+                    meta_text = meta_block.get_text(' ', strip=True)
+                    # Split on common separators
+                    parts = [p.strip() for p in re.split(r'[·•|]', meta_text) if p.strip()]
+                    if len(parts) >= 2:
+                        author = parts[0] or author
+                        date_val = parts[1] or date_val
+
+                # Fallback selectors
+                if author == 'Unknown':
+                    author = first_text(item, ['.author', '.username', '[class*="author"]']) or 'Unknown'
+                if date_val == 'Unknown':
+                    # time element or date class
+                    time_elem = item.select_one('.date, time, [class*="date"]')
+                    if time_elem:
+                        date_val = time_elem.get('datetime') or time_elem.get('title') or time_elem.get_text(strip=True) or 'Unknown'
+
+                # Compose legacy fields
+                snippet = description_text
+                metadata = f"author={author} date={date_val} votes={votes} comments={comments}".strip()
+
                 results.append({
-                    "title": title,
-                    "link": link,
-                    "snippet": snippet,
-                    "metadata": metadata,
-                    "page": page_num
+                    'title': title,
+                    'link': link,
+                    'description_html': description_html or 'No description',
+                    'description_text': description_text or 'No description',
+                    'votes': votes,
+                    'comments': comments,
+                    'author': author,
+                    'date': date_val,
+                    'snippet': snippet,      # backward compatibility
+                    'metadata': metadata,    # backward compatibility / quick summary
+                    'page': page_num,
+                    'index': idx
                 })
-                
             except Exception as e:
-                log(f"Error extracting result: {str(e)}", "WARNING")
+                log(f"Error extracting search result {idx}: {str(e)}", "WARNING")
                 continue
-        
+
         return results
     
     async def _go_to_next_search_page(self, driver: webdriver.Chrome, soup: BeautifulSoup) -> bool:
@@ -915,7 +1023,19 @@ if forum_mcp:
             headless: Run browser in headless mode (default: True)
         
         Returns:
-            Search results with analysis
+                        Search results with analysis. Each result item now includes:
+                            - title: Post title
+                            - link: Absolute URL to the post (may be a tracking redirect)
+                            - description_html: Raw HTML snippet/preview
+                            - description_text: Text version of snippet
+                            - votes: Vote count (raw text, may include locale suffix)
+                            - comments: Comment count (raw text)
+                            - author: Parsed author name (or 'Unknown')
+                            - date: Parsed date/datetime string when available
+                            - snippet: Alias of description_text (backward compatibility)
+                            - metadata: Compact string summary (author/date/votes/comments)
+                            - page: Page number where the result appeared
+                            - index: Index within that page (0-based)
         """
         try:
             return await forum_client.search_forum_posts(email, password, search_query, max_results, headless)
