@@ -26,6 +26,9 @@ from bs4 import BeautifulSoup
 from mcp.server.fastmcp import FastMCP
 from pydantic import BaseModel, Field, EmailStr
 
+from pathlib import Path
+
+
 # Configure logging
 logging.basicConfig(level=logging.INFO, format='%(asctime)s - %(levelname)s - %(message)s')
 logger = logging.getLogger(__name__)
@@ -81,8 +84,8 @@ class BrainApiClient:
         print(f"[{level}] {message}", file=sys.stderr)
     
     async def authenticate(self, email: str, password: str) -> Dict[str, Any]:
-        """Authenticate with WorldQuant BRAIN platform using Basic Authentication."""
-        self.log("🔐 Starting Basic Authentication process...", "INFO")
+        """Authenticate with WorldQuant BRAIN platform with biometric support."""
+        self.log("🔐 Starting Authentication process...", "INFO")
         
         try:
             # Store credentials for potential re-authentication
@@ -106,7 +109,7 @@ class BrainApiClient:
             
             # Check for successful authentication (status code 201)
             if response.status_code == 201:
-                self.log("✅ Basic Authentication successful", "SUCCESS")
+                self.log("✅ Authentication successful", "SUCCESS")
                 
                 # Check if JWT token was automatically stored by session
                 jwt_token = self.session.cookies.get('t')
@@ -120,10 +123,26 @@ class BrainApiClient:
                     'user': {'email': email},
                     'status': 'authenticated',
                     'permissions': ['read', 'write'],
-                    'message': 'Basic Authentication successful',
+                    'message': 'Authentication successful',
                     'status_code': response.status_code,
                     'has_jwt': jwt_token is not None
                 }
+            
+            # Check if biometric authentication is required (401 with persona)
+            elif response.status_code == 401:
+                www_auth = response.headers.get("WWW-Authenticate")
+                location = response.headers.get("Location")
+                
+                if www_auth == "persona" and location:
+                    self.log("🔴 Biometric authentication required", "INFO")
+                    
+                    # Handle biometric authentication
+                    from urllib.parse import urljoin
+                    biometric_url = urljoin(response.url, location)
+                    
+                    return await self._handle_biometric_auth(biometric_url, email)
+                else:
+                    raise Exception("Incorrect email or password")
             else:
                 raise Exception(f"Authentication failed with status code: {response.status_code}")
                     
@@ -134,6 +153,97 @@ class BrainApiClient:
             self.log(f"❌ Authentication failed: {str(e)}", "ERROR")
             raise
     
+    async def _handle_biometric_auth(self, biometric_url: str, email: str) -> Dict[str, Any]:
+        """Handle biometric authentication using browser automation."""
+        self.log("🌐 Starting biometric authentication...", "INFO")
+        
+        try:
+            # Import selenium for browser automation
+            from selenium import webdriver
+            from selenium.webdriver.chrome.options import Options
+            import time
+            
+            # Setup Chrome options
+            options = Options()
+            options.add_argument('--no-sandbox')
+            options.add_argument('--disable-dev-shm-usage')
+            
+            driver = None
+            try:
+                # Open browser with timeout
+                driver = webdriver.Chrome(options=options)
+                # Set a short timeout so it doesn't wait forever
+                driver.set_page_load_timeout(80)  # Only wait 5 seconds
+                
+                self.log("🌐 Opening browser for biometric authentication...", "INFO")
+                
+                # Try to open the URL but handle timeout
+                try:
+                    driver.get(biometric_url)
+                    self.log("✅ Browser page loaded successfully", "SUCCESS")
+                except Exception as timeout_error:
+                    self.log(f"⚠️ Page load timeout (expected): {str(timeout_error)[:50]}...", "WARNING")
+                    self.log("✅ Browser window is open for biometric authentication", "INFO")
+                
+                # Print instructions
+                print("\n" + "="*60, file=sys.stderr)
+                print("🔒 BIOMETRIC AUTHENTICATION REQUIRED", file=sys.stderr)
+                print("="*60, file=sys.stderr)
+                print("🌐 Browser window is open with biometric authentication page", file=sys.stderr)
+                print("🔧 Complete the biometric authentication in the browser", file=sys.stderr)
+                print("⏳ The system will automatically check when you're done...", file=sys.stderr)
+                print("="*60, file=sys.stderr)
+                
+                # Keep checking until authentication is complete
+                max_attempts = 60  # 5 minutes maximum (60 * 5 seconds)
+                attempt = 0
+                
+                while attempt < max_attempts:
+                    time.sleep(5)  # Check every 5 seconds
+                    attempt += 1
+                    
+                    # Check if authentication completed
+                    check_response = self.session.post(biometric_url)
+                    self.log(f"🔄 Checking authentication status (attempt {attempt}/{max_attempts}): {check_response.status_code}", "INFO")
+                    
+                    if check_response.status_code == 201:
+                        self.log("✅ Biometric authentication successful!", "SUCCESS")
+                        
+                        # Close browser
+                        driver.quit()
+                        
+                        # Check JWT token
+                        jwt_token = self.session.cookies.get('t')
+                        if jwt_token:
+                            self.log("✅ JWT token received", "SUCCESS")
+                        
+                        # Return success response
+                        return {
+                            'user': {'email': email},
+                            'status': 'authenticated',
+                            'permissions': ['read', 'write'],
+                            'message': 'Biometric authentication successful',
+                            'status_code': check_response.status_code,
+                            'has_jwt': jwt_token is not None
+                        }
+                
+                # If we get here, authentication timed out
+                if driver:
+                    driver.quit()
+                raise Exception("Biometric authentication timed out")
+                
+            except Exception as driver_error:
+                if driver:
+                    try:
+                        driver.quit()
+                    except:
+                        pass
+                raise Exception(f"Browser automation error: {driver_error}")
+                
+        except Exception as e:
+            self.log(f"❌ Biometric authentication failed: {str(e)}", "ERROR")
+            raise
+    
     async def is_authenticated(self) -> bool:
         """Check if currently authenticated using JWT token."""
         try:
@@ -263,7 +373,7 @@ class BrainApiClient:
             raise
     
     async def get_datasets(self, instrument_type: str = "EQUITY", region: str = "USA", 
-                          delay: int = 1, universe: str = "TOP3000", theme: str = "false") -> Dict[str, Any]:
+                          delay: int = 1, universe: str = "TOP3000", theme: str = "false", search: Optional[str] = None) -> Dict[str, Any]:
         """Get available datasets."""
         await self.ensure_authenticated()
         
@@ -276,9 +386,14 @@ class BrainApiClient:
                 'theme': theme
             }
             
+            if search:
+                params['search'] = search
+            
             response = self.session.get(f"{self.base_url}/data-sets", params=params)
             response.raise_for_status()
-            return response.json()
+            response = response.json()
+            response['extraNote'] = "if your returned result is 0, you may want to check your parameter by using get_platform_setting_options tool to got correct parameter"
+            return response
         except Exception as e:
             self.log(f"Failed to get datasets: {str(e)}", "ERROR")
             raise
@@ -310,35 +425,67 @@ class BrainApiClient:
             
             response = self.session.get(f"{self.base_url}/data-fields", params=params)
             response.raise_for_status()
-            return response.json()
+            response = response.json()
+            response['extraNote'] = "if your returned result is 0, you may want to check your parameter by using get_platform_setting_options tool to got correct parameter"
+            return response
         except Exception as e:
             self.log(f"Failed to get datafields: {str(e)}", "ERROR")
             raise
     
-    async def get_alpha_pnl(self, alpha_id: str, pnl_type: str = "pnl") -> Dict[str, Any]:
+    async def get_alpha_pnl(self, alpha_id: str) -> Dict[str, Any]:
         """Get PnL data for an alpha."""
         await self.ensure_authenticated()
         
         try:
-            params = {'type': pnl_type}
-            response = self.session.get(f"{self.base_url}/alphas/{alpha_id}/recordsets/{pnl_type}", params=params)
+            response = self.session.get(f"{self.base_url}/alphas/{alpha_id}/recordsets/pnl")
             response.raise_for_status()
-            return response.json()
+            # Some alphas may return 204 No Content or an empty body
+            text = (response.text or "").strip()
+            if not text:
+                return {}
+            try:
+                return response.json()
+            except Exception as parse_err:
+                self.log(f"PnL JSON parse failed for {alpha_id}: {parse_err}", "WARNING")
+                return {}
         except Exception as e:
             self.log(f"Failed to get alpha PnL: {str(e)}", "ERROR")
             raise
     
-    async def get_user_alphas(self, stage: str = "IS", limit: int = 100, offset: int = 0) -> Dict[str, Any]:
-        """Get user's alphas."""
+    async def get_user_alphas(
+        self,
+        stage: str = "OS",
+        limit: int = 30,
+        offset: int = 0,
+        start_date: Optional[str] = None,
+        end_date: Optional[str] = None,
+        submission_start_date: Optional[str] = None,
+        submission_end_date: Optional[str] = None,
+        order: Optional[str] = None,
+        hidden: Optional[bool] = None,
+    ) -> Dict[str, Any]:
+        """Get user's alphas with advanced filtering."""
         await self.ensure_authenticated()
         
         try:
             params = {
-                'stage': stage,
-                'limit': limit,
-                'offset': offset
+                "stage": stage,
+                "limit": limit,
+                "offset": offset,
             }
-            
+            if start_date:
+                params["dateCreated>"] = start_date
+            if end_date:
+                params["dateCreated<"] = end_date
+            if submission_start_date:
+                params["dateSubmitted>"] = submission_start_date
+            if submission_end_date:
+                params["dateSubmitted<"] = submission_end_date
+            if order:
+                params["order"] = order
+            if hidden is not None:
+                params["hidden"] = str(hidden).lower()
+
             response = self.session.get(f"{self.base_url}/users/self/alphas", params=params)
             response.raise_for_status()
             return response.json()
@@ -472,19 +619,122 @@ class BrainApiClient:
     # get_messages_summary function removed as requested
 
     async def get_messages(self, limit: Optional[int] = None, offset: int = 0) -> Dict[str, Any]:
-        """Get messages for the current user with optional pagination."""
+        """Get messages for the current user with optional pagination.
+
+        Image / large binary payload mitigation:
+          Some messages embed base64 encoded images (e.g. <img src="data:image/png;base64,..."/>).
+          Returning full base64 can explode token usage for an LLM client. We post-process each
+          message description and (by default) extract embedded base64 images to disk and replace
+          them with lightweight placeholders while preserving context.
+
+        Strategies (environment driven in future – currently parameterless public API):
+          - placeholder (default): save images to message_images/ and replace with marker text.
+          - ignore: strip image tags entirely, leaving a note.
+          - keep: leave description unchanged (unsafe for LLM token limits).
+
+        A message dict gains an 'extracted_images' list when images are processed.
+        """
         await self.ensure_authenticated()
-        
+
+        import re, base64, pathlib
+
+        image_handling = os.environ.get("BRAIN_MESSAGE_IMAGE_MODE", "placeholder").lower()
+        save_dir = pathlib.Path("message_images")
+
+        from typing import Tuple
+        def process_description(desc: str, message_id: str) -> Tuple[str, List[str]]:
+            if not desc or image_handling == "keep":
+                return desc, []
+            attachments: List[str] = []
+            # Regex to capture full <img ...> tag with data URI
+            img_tag_pattern = re.compile(r"<img[^>]+src=\"(data:image/[^\"]+)\"[^>]*>", re.IGNORECASE)
+            # Iterate over unique matches to avoid double work
+            matches = list(img_tag_pattern.finditer(desc))
+            if not matches:
+                # Additional heuristic: very long base64-looking token inside quotes followed by </img>
+                # (legacy format noted by user sample). Replace with placeholder.
+                heuristic_pattern = re.compile(r"([A-Za-z0-9+/]{500,}={0,2})\"\s*</img>")
+                if image_handling != "keep" and heuristic_pattern.search(desc):
+                    placeholder = "[Embedded image removed - large base64 sequence truncated]"
+                    return heuristic_pattern.sub(placeholder + "</img>", desc), []
+                return desc, []
+
+            # Ensure save directory exists only if we will store something
+            if image_handling == "placeholder" and not save_dir.exists():
+                try:
+                    save_dir.mkdir(parents=True, exist_ok=True)
+                except Exception as e:
+                    self.log(f"Could not create image save directory: {e}", "WARNING")
+
+            new_desc = desc
+            for idx, match in enumerate(matches, start=1):
+                data_uri = match.group(1)  # data:image/...;base64,XXXX
+                if not data_uri.lower().startswith("data:image"):
+                    continue
+                # Split header and base64 payload
+                if "," not in data_uri:
+                    continue
+                header, b64_data = data_uri.split(",", 1)
+                mime_part = header.split(";")[0]  # data:image/png
+                ext = "png"
+                if "/" in mime_part:
+                    ext = mime_part.split("/")[1]
+                safe_ext = (ext or "img").split("?")[0]
+                placeholder_text = "[Embedded image]"
+                if image_handling == "ignore":
+                    replacement = f"[Image removed: {safe_ext}]"
+                elif image_handling == "placeholder":
+                    # Try decode & save
+                    file_name = f"{message_id}_{idx}.{safe_ext}"
+                    file_path = save_dir / file_name
+                    try:
+                        # Guard extremely large strings (>5MB ~ 6.7M base64 chars) to avoid memory blow
+                        if len(b64_data) > 7_000_000:
+                            raise ValueError("Image too large to decode safely")
+                        with open(file_path, "wb") as f:
+                            f.write(base64.b64decode(b64_data))
+                        attachments.append(str(file_path))
+                        replacement = f"[Image extracted -> {file_path}]"
+                    except Exception as e:
+                        self.log(f"Failed to decode embedded image in message {message_id}: {e}", "WARNING")
+                        replacement = "[Image extraction failed - content omitted]"
+                else:  # keep
+                    replacement = placeholder_text  # shouldn't be used since early return, but safe
+                # Replace only the matched tag (not global) – use re.sub with count=1 on substring slice
+                # Safer to operate on new_desc using the exact matched string
+                original_tag = match.group(0)
+                new_desc = new_desc.replace(original_tag, replacement, 1)
+            return new_desc, attachments
+
         try:
             params = {}
             if limit is not None:
                 params['limit'] = limit
             if offset > 0:
                 params['offset'] = offset
-            
+
             response = self.session.get(f"{self.base_url}/users/self/messages", params=params)
             response.raise_for_status()
-            return response.json()
+            data = response.json()
+
+            # Post-process results for image handling
+            results = data.get('results', [])
+            for msg in results:
+                try:
+                    desc = msg.get('description')
+                    processed_desc, attachments = process_description(desc, msg.get('id', 'msg'))
+                    if attachments or desc != processed_desc:
+                        msg['description'] = processed_desc
+                        if attachments:
+                            msg['extracted_images'] = attachments
+                        else:
+                            # If changed but no attachments (ignore mode) mark sanitized
+                            msg['sanitized'] = True
+                except Exception as inner_e:
+                    self.log(f"Failed to sanitize message {msg.get('id')}: {inner_e}", "WARNING")
+            data['results'] = results
+            data['image_handling'] = image_handling
+            return data
         except Exception as e:
             self.log(f"Failed to get messages: {str(e)}", "ERROR")
             raise
@@ -547,9 +797,11 @@ class BrainApiClient:
         await self.ensure_authenticated()
         
         try:
-            response = self.session.get(f"{self.base_url}/alphas/{alpha_id}/recordsets/production-correlation")
+            response = self.session.get(f"{self.base_url}/alphas/{alpha_id}/correlations/prod")
             response.raise_for_status()
-            return response.json()
+            if response.text:
+                return response.json()
+            return {}  # Return empty dict for empty response
         except Exception as e:
             self.log(f"Failed to get production correlation: {str(e)}", "ERROR")
             raise
@@ -559,9 +811,11 @@ class BrainApiClient:
         await self.ensure_authenticated()
         
         try:
-            response = self.session.get(f"{self.base_url}/alphas/{alpha_id}/recordsets/self-correlation")
+            response = self.session.get(f"{self.base_url}/alphas/{alpha_id}/correlations/self")
             response.raise_for_status()
-            return response.json()
+            if response.text:
+                return response.json()
+            return {}  # Return empty dict for empty response
         except Exception as e:
             self.log(f"Failed to get self correlation: {str(e)}", "ERROR")
             raise
@@ -710,8 +964,7 @@ class BrainApiClient:
             self.log(f"Failed to get user activities: {str(e)}", "ERROR")
             raise
 
-    async def get_pyramid_multipliers(self, region: Optional[str] = None, delay: Optional[int] = None,
-                                    category: Optional[str] = None) -> Dict[str, Any]:
+    async def get_pyramid_multipliers(self) -> Dict[str, Any]:
         """Get current pyramid multipliers showing BRAIN's encouragement levels."""
         await self.ensure_authenticated()
         
@@ -724,26 +977,43 @@ class BrainApiClient:
             self.log(f"Failed to get pyramid multipliers: {str(e)}", "ERROR")
             raise
 
-    async def get_pyramid_alphas(self, region: Optional[str] = None, delay: Optional[int] = None,
-                               category: Optional[str] = None, start_date: Optional[str] = None,
+    async def get_pyramid_alphas(self, start_date: Optional[str] = None,
                                end_date: Optional[str] = None) -> Dict[str, Any]:
         """Get user's current alpha distribution across pyramid categories."""
         await self.ensure_authenticated()
         
         try:
             params = {}
-            if region:
-                params['region'] = region
-            if delay is not None:
-                params['delay'] = delay
-            if category:
-                params['category'] = category
             if start_date:
                 params['startDate'] = start_date
             if end_date:
                 params['endDate'] = end_date
             
-            response = self.session.get(f"{self.base_url}/pyramid/alphas", params=params)
+            # Try the user-specific activities endpoint first (like pyramid-multipliers)
+            response = self.session.get(f"{self.base_url}/users/self/activities/pyramid-alphas", params=params)
+            
+            # If that fails, try alternative endpoints
+            if response.status_code == 404:
+                # Try alternative endpoint structure
+                response = self.session.get(f"{self.base_url}/users/self/pyramid/alphas", params=params)
+                
+                if response.status_code == 404:
+                    # Try yet another alternative
+                    response = self.session.get(f"{self.base_url}/activities/pyramid-alphas", params=params)
+                    
+                    if response.status_code == 404:
+                        # Return an informative error with what we tried
+                        return {
+                            "error": "Pyramid alphas endpoint not found",
+                            "tried_endpoints": [
+                                "/users/self/activities/pyramid-alphas",
+                                "/users/self/pyramid/alphas", 
+                                "/activities/pyramid-alphas",
+                                "/pyramid/alphas"
+                            ],
+                            "suggestion": "This endpoint may not be available in the current API version"
+                        }
+            
             response.raise_for_status()
             return response.json()
         except Exception as e:
@@ -795,7 +1065,7 @@ class BrainApiClient:
             self.log(f"Failed to get competition agreement: {str(e)}", "ERROR")
             raise
 
-    async def get_instrument_options(self) -> Dict[str, Any]:
+    async def get_platform_setting_options(self) -> Dict[str, Any]:
         """Get available instrument types, regions, delays, and universes."""
         await self.ensure_authenticated()
         
@@ -945,42 +1215,80 @@ brain_client = BrainApiClient()
 # Configuration management
 CONFIG_FILE = "user_config.json"
 
+def _resolve_config_path(for_write: bool = False) -> str:
+    """
+    Resolve the config file path with this priority:
+    1) BRAIN_CONFIG_PATH (file or directory)
+    2) Directory of running script when available, else current working directory
+    3) Current working directory
+
+    When for_write=True, returns the preferred path even if it doesn't exist yet.
+    """
+    # 1) Explicit override via env var
+    env_path = os.environ.get("BRAIN_CONFIG_PATH")
+    if env_path:
+        p = Path(env_path).expanduser()
+        target = p / CONFIG_FILE if p.is_dir() else p
+        # For read, only if it exists; for write, allow regardless
+        if for_write or target.exists():
+            return str(target.resolve())
+
+    # 2) Script/module directory when available, else CWD (works in notebooks)
+    base_dir = Path.cwd()
+    try:
+        # __file__ is not defined in notebooks; this will fail there and keep CWD
+        script_dir = Path(__file__).resolve().parent  # type: ignore[name-defined]
+        base_dir = script_dir
+    except Exception:
+        # Fall back to current working directory for notebooks/REPL
+        pass
+
+    module_path = base_dir / CONFIG_FILE
+    if not for_write and module_path.exists():
+        return str(module_path.resolve())
+
+    # 3) Fallback to CWD for backward compatibility
+    cwd_path = Path.cwd() / CONFIG_FILE
+    if not for_write and cwd_path.exists():
+        return str(cwd_path.resolve())
+
+    # For writes (or when nothing exists), prefer the module/base directory
+    return str(module_path.resolve())
+
 def load_config() -> Dict[str, Any]:
-    """Load configuration from file."""
-    if os.path.exists(CONFIG_FILE):
+    """Load configuration from file with robust path resolution.
+
+    Looks for the config in this order: BRAIN_CONFIG_PATH -> module directory -> CWD.
+    Returns an empty dict when not found or on error.
+    """
+    path = _resolve_config_path(for_write=False)
+    if os.path.exists(path):
         try:
-            with open(CONFIG_FILE, 'r') as f:
+            with open(path, 'r', encoding='utf-8') as f:
                 return json.load(f)
         except Exception as e:
-            logger.error(f"Failed to load config: {e}")
+            logger.error(f"Failed to load config from '{path}': {e}")
     return {}
 
-def load_brain_credentials() -> Optional[tuple]:
-    """Load credentials from .brain_credentials file in home directory."""
-    try:
-        from os.path import expanduser
-        credentials_file = expanduser('~/.brain_credentials')
-        if os.path.exists(credentials_file):
-            with open(credentials_file, 'r') as f:
-                credentials = json.load(f)
-                if isinstance(credentials, list) and len(credentials) == 2:
-                    return tuple(credentials)
-    except Exception as e:
-        logger.error(f"Failed to load .brain_credentials: {e}")
-    return None
 
 def save_config(config: Dict[str, Any]):
-    """Save configuration to file."""
+    """Save configuration to file using the resolved config path.
+
+    Uses BRAIN_CONFIG_PATH if set; otherwise writes next to this module.
+    Ensures the target directory exists.
+    """
     try:
-        with open(CONFIG_FILE, 'w') as f:
-            json.dump(config, f, indent=2)
+        path = _resolve_config_path(for_write=True)
+        os.makedirs(os.path.dirname(path), exist_ok=True)
+        with open(path, 'w', encoding='utf-8') as f:
+            json.dump(config, f, indent=2, ensure_ascii=False)
     except Exception as e:
         logger.error(f"Failed to save config: {e}")
 
 # MCP Tools
 
 @mcp.tool()
-async def authenticate(email: str = "", password: str = "") -> Dict[str, Any]:
+async def authenticate(email: Optional[str] = "", password: Optional[str] = "") -> Dict[str, Any]:
     """
     🔐 Authenticate with WorldQuant BRAIN platform.
     
@@ -994,20 +1302,12 @@ async def authenticate(email: str = "", password: str = "") -> Dict[str, Any]:
         Authentication result with user info and permissions
     """
     try:
-        # First try to load from .brain_credentials file
-        brain_creds = load_brain_credentials()
-        if brain_creds and not email and not password:
-            email, password = brain_creds
-            print(f"📧 Using credentials from .brain_credentials file: {email}")
-        
-        # If still no credentials, try config file
-        if not email or not password:
-            config = load_config()
-            if 'credentials' in config:
-                if not email:
-                    email = config['credentials'].get('email', '')
-                if not password:
-                    password = config['credentials'].get('password', '')
+        config = load_config()
+        if 'credentials' in config:
+            if not email:
+                email = config['credentials'].get('email', '')
+            if not password:
+                password = config['credentials'].get('password', '')
         
         if not email or not password:
             return {"error": "Email and password required. Either provide them as arguments, configure them in user_config.json, or create a .brain_credentials file in your home directory with format: [\"email\", \"password\"]"}
@@ -1225,37 +1525,85 @@ async def get_datafields(
         return {"error": str(e)}
 
 @mcp.tool()
-async def get_alpha_pnl(alpha_id: str, pnl_type: str = "pnl") -> Dict[str, Any]:
+async def get_alpha_pnl(alpha_id: str) -> Dict[str, Any]:
     """
     📈 Get PnL (Profit and Loss) data for an alpha.
     
     Args:
         alpha_id: The ID of the alpha
-        pnl_type: Type of PnL data ("pnl" for cumulative, "daily-pnl" for daily)
     
     Returns:
         PnL data for the alpha
     """
     try:
-        return await brain_client.get_alpha_pnl(alpha_id, pnl_type)
+        return await brain_client.get_alpha_pnl(alpha_id)
     except Exception as e:
         return {"error": str(e)}
 
 @mcp.tool()
-async def get_user_alphas(stage: str = "IS", limit: int = 100, offset: int = 0) -> Dict[str, Any]:
+async def get_user_alphas(
+    stage: str = "IS",
+    limit: int = 30,
+    offset: int = 0,
+    start_date: Optional[str] = None,
+    end_date: Optional[str] = None,
+    submission_start_date: Optional[str] = None,
+    submission_end_date: Optional[str] = None,
+    order: Optional[str] = None,
+    hidden: Optional[bool] = None,
+) -> Dict[str, Any]:
     """
-    👤 Get user's alphas.
-    
+    👤 Get user's alphas with advanced filtering, pagination, and sorting.
+
+    This tool retrieves a list of your alphas, allowing for detailed filtering based on stage,
+    creation date, submission date, and visibility. It also supports pagination and custom sorting.
+
     Args:
-        stage: Alpha stage ("IS" for in-sample, "OS" for out-of-sample)
-        limit: Maximum number of alphas to return
-        offset: Offset for pagination
-    
+        stage (str): The stage of the alphas to retrieve.
+            - "IS": In-Sample (alphas that have not been submitted).
+            - "OS": Out-of-Sample (alphas that have been submitted).
+            Defaults to "IS".
+        limit (int): The maximum number of alphas to return in a single request.
+            For example, `limit=50` will return at most 50 alphas. Defaults to 30.
+        offset (int): The number of alphas to skip from the beginning of the list.
+            Used for pagination. For example, `limit=50, offset=50` will retrieve alphas 51-100.
+            Defaults to 0.
+        start_date (Optional[str]): The earliest creation date for the alphas to be included.
+            Filters for alphas created on or after this date.
+            Example format: "2023-01-01T00:00:00Z".
+        end_date (Optional[str]): The latest creation date for the alphas to be included.
+            Filters for alphas created before this date.
+            Example format: "2023-12-31T23:59:59Z".
+        submission_start_date (Optional[str]): The earliest submission date for the alphas.
+            Only applies to "OS" alphas. Filters for alphas submitted on or after this date.
+            Example format: "2024-01-01T00:00:00Z".
+        submission_end_date (Optional[str]): The latest submission date for the alphas.
+            Only applies to "OS" alphas. Filters for alphas submitted before this date.
+            Example format: "2024-06-30T23:59:59Z".
+        order (Optional[str]): The sorting order for the returned alphas.
+            Prefix with a hyphen (-) for descending order.
+            Examples: "name" (sort by name ascending), "-dateSubmitted" (sort by submission date descending).
+        hidden (Optional[bool]): Filter alphas based on their visibility.
+            - `True`: Only return hidden alphas.
+            - `False`: Only return non-hidden alphas.
+            If not provided, both hidden and non-hidden alphas are returned.
+
     Returns:
-        User's alphas
+        Dict[str, Any]: A dictionary containing a list of alpha details under the 'results' key,
+        along with pagination information. If an error occurs, it returns a dictionary with an 'error' key.
     """
     try:
-        return await brain_client.get_user_alphas(stage, limit, offset)
+        return await brain_client.get_user_alphas(
+            stage=stage,
+            limit=limit,
+            offset=offset,
+            start_date=start_date,
+            end_date=end_date,
+            submission_start_date=submission_start_date,
+            submission_end_date=submission_end_date,
+            order=order,
+            hidden=hidden,
+        )
     except Exception as e:
         return {"error": str(e)}
 
@@ -1333,35 +1681,7 @@ async def save_simulation_data(simulation_id: str, filename: str) -> Dict[str, A
     except Exception as e:
         return {"error": str(e)}
 
-@mcp.tool()
-async def analyze_alpha_performance(alpha_id: str) -> Dict[str, Any]:
-    """
-    📊 Comprehensive alpha performance analysis.
-    
-    Args:
-        alpha_id: The alpha ID to analyze
-    
-    Returns:
-        Comprehensive performance analysis
-    """
-    try:
-        # Get alpha details
-        alpha_details = await brain_client.get_alpha_details(alpha_id)
-        
-        # Get PnL data
-        pnl_data = await brain_client.get_alpha_pnl(alpha_id)
-        
-        # Get yearly stats if available
-        yearly_stats = await brain_client.get_alpha_yearly_stats(alpha_id)
-        
-        return {
-            "alpha_details": alpha_details,
-            "pnl_data": pnl_data,
-            "yearly_stats": yearly_stats,
-            "analysis_timestamp": datetime.now().isoformat()
-        }
-    except Exception as e:
-        return {"error": str(e)}
+
 
 @mcp.tool()
 async def get_operators() -> Dict[str, Any]:
@@ -1618,21 +1938,19 @@ async def get_user_activities(user_id: str, grouping: Optional[str] = None) -> D
         return {"error": str(e)}
 
 @mcp.tool()
-async def get_pyramid_multipliers(region: Optional[str] = None, delay: Optional[int] = None, 
-                                category: Optional[str] = None) -> Dict[str, Any]:
+async def get_pyramid_multipliers() -> Dict[str, Any]:
     """Get current pyramid multipliers showing BRAIN's encouragement levels."""
     try:
-        return await brain_client.get_pyramid_multipliers(region, delay, category)
+        return await brain_client.get_pyramid_multipliers()
     except Exception as e:
         return {"error": str(e)}
 
 @mcp.tool()
-async def get_pyramid_alphas(region: Optional[str] = None, delay: Optional[int] = None,
-                           category: Optional[str] = None, start_date: Optional[str] = None,
+async def get_pyramid_alphas(start_date: Optional[str] = None,
                            end_date: Optional[str] = None) -> Dict[str, Any]:
     """Get user's current alpha distribution across pyramid categories."""
     try:
-        return await brain_client.get_pyramid_alphas(region, delay, category, start_date, end_date)
+        return await brain_client.get_pyramid_alphas(start_date, end_date)
     except Exception as e:
         return {"error": str(e)}
 
@@ -1661,10 +1979,18 @@ async def get_competition_agreement(competition_id: str) -> Dict[str, Any]:
         return {"error": str(e)}
 
 @mcp.tool()
-async def get_instrument_options() -> Dict[str, Any]:
-    """Get available instrument types, regions, delays, and universes."""
+async def get_platform_setting_options() -> Dict[str, Any]:
+    """Discover valid simulation setting options (instrument types, regions, delays, universes, neutralization).
+
+    Use this when a simulation request might contain an invalid/mismatched setting. If an AI or user supplies
+    incorrect parameters (e.g., wrong region for an instrument type), call this tool to retrieve the authoritative
+    option sets and correct the inputs before proceeding.
+
+    Returns:
+        A structured list of valid combinations and choice lists to validate or fix simulation settings.
+    """
     try:
-        return await brain_client.get_instrument_options()
+        return await brain_client.get_platform_setting_options()
     except Exception as e:
         return {"error": str(e)}
 
